
## CATO-CLI - mutation.policy.terminalServer:
[Click here](https://api.catonetworks.com/documentation/#mutation-terminalServer) for documentation on this operation.

### Usage for mutation.policy.terminalServer:

`catocli mutation policy terminalServer -h`
